@@ -1,6 +1,8 @@
 #include <limits.h>
 #include <float.h>
 
+#include "general.h"
+#include "error.h"
 #include "contain.h"
 #include "utils.h"
 #include "binpart.h"
