@@ -35,6 +35,9 @@ public:
    //PseudoRandom rnd ;
    forestTree(void) {}
    ~forestTree(void) {} 
+   void operator= (forestTree &Source) { copy(Source); };
+   void copy(forestTree &Source) ;
+;
 } ;
 
 
